#
# spec file for package ocaml
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2010 Andrew Psaltis <ampsaltis at gmail dot com>
# Copyright (c) 2011 Andrew Psaltis <ampsaltis at gmail dot com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ocaml
Version:        4.01.0
Release:        2.2
%define doc_version 4.01
%define do_opt 0
%ifarch %arm %ix86 ppc ppc64 x86_64
%define do_opt 1
%endif
# http://caml.inria.fr/pub/distrib/ocaml-%{doc_version}/
Source0:        ocaml-%{version}.tar.xz
Source1:        ocaml-%{doc_version}-refman-html.tar.xz
Source2:        ocaml-%{doc_version}-refman.ps.xz
Source3:        ocaml-%{doc_version}-refman.info.tar.xz
Source4:        rpmlintrc
Patch0:         ocaml-3.00-camldebug_el.patch
Patch2:         ocaml-3.04-ocamltags--no-site-start.patch
# FIX-UPSTREAM remove rpath from make file
Patch3:         ocaml-rpath.patch
# FIX-UPSTREAM pass RPM_OPT_FLAGS to build
Patch4:         ocaml-configure-Allow-user-defined-C-compiler-flags.patch
Patch5:         ocaml-3.08.3-gcc4.patch
Patch7:         ocaml-3.09-emacs_localcompile.patch
# FIX-UPSTREAM use mkstemp to fix rpmlint warning
Patch8:         ocaml-yacc-Use-mkstemp-instead-of-mktemp.patch
# FIX-UPSTREAM enable build on PowerPC 64bit platform.
Patch9:         ocaml-ppc64.patch
Url:            http://caml.inria.fr/
Summary:        The Objective Caml Compiler and Programming Environment
License:        QPL-1.0 and SUSE-LGPL-2.0-with-linking-exception
Group:          Development/Languages/Other
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
PreReq:         %install_info_prereq
BuildRequires:	xz
BuildRequires:  emacs-nox
BuildRequires:  fdupes
BuildRequires:  gdbm-devel
BuildRequires:  ncurses-devel
BuildRequires:  tk-devel
# This gets ocamlobjinfo to work with .cmxs files
BuildRequires:  binutils-devel
%if %{do_opt}
Provides:       ocaml(ocaml.opt) = %{version}
%endif
Provides:       ocaml(compiler) = %{version}
Requires:       ocaml-runtime = %{version}

# This ensures that the find_provides/find_requires calls ocamlobjinfo correctly.
%global __ocaml_requires_opts -c -f "%{buildroot}%{_bindir}/ocamlrun %{buildroot}%{_bindir}/ocamlobjinfo"
%global __ocaml_provides_opts -f "%{buildroot}%{_bindir}/ocamlrun %{buildroot}%{_bindir}/ocamlobjinfo"

%description
Objective Caml is a high-level, strongly-typed, functional and
object-oriented programming language from the ML family of languages.

This package comprises two batch compilers (a fast bytecode compiler
and an optimizing native-code compiler), an interactive top level
system, Lex&Yacc tools, a replay debugger, and a comprehensive library.


%package runtime
Summary:        The Objective Caml Compiler and Programming Environment
License:        QPL-1.0
Group:          Development/Languages/Other
Provides:       ocaml(runtime) = %{version}

%description runtime
Objective Caml is a high-level, strongly-typed, functional and
object-oriented programming language from the ML family of languages.

This package contains the runtime environment needed to run Objective
Caml bytecode.


%package source
Summary:        Source code for Objective Caml libraries
License:        QPL-1.0 and SUSE-LGPL-2.0-with-linking-exception
Group:          Development/Languages/Other
Requires:       ocaml = %{version}

%description source
Source code for Objective Caml libraries.


%package x11
Summary:        X11 support for Objective Caml
License:        SUSE-LGPL-2.0-with-linking-exception
Group:          System/Libraries
Requires:       ocaml-runtime = %{version}

%description x11
X11 support for Objective Caml.



%package labltk
Summary:        The Objective Caml Compiler and Programming Environment
License:        SUSE-LGPL-2.0-with-linking-exception
Group:          System/Libraries
Requires:       ocaml = %{version}
Requires:       ocaml(runtime) = %{version}

%description labltk
Labltk is a library for interfacing Objective Caml with the scripting
language Tcl/Tk.

This package contains the runtime files.



%package labltk-devel
Summary:        Development files for labltk
License:        SUSE-LGPL-2.0-with-linking-exception
Group:          Development/Libraries/Other
Requires:       %{name}-labltk = %{version}
Requires:       ocaml = %{version}
Requires:       tcl-devel
Requires:       tk-devel
Requires:       xorg-x11-libX11-devel

%description labltk-devel
Labltk is a library for interfacing Objective Caml with the scripting
language Tcl/Tk.

This package contains the development files.  It includes the ocaml
browser for code editing and library browsing.



%package camlp4
Summary:        Pre-Processor-Pretty-Printer for Objective Caml
License:        SUSE-LGPL-2.0-with-linking-exception
Group:          Development/Languages/Other
Requires:       ocaml-runtime = %{version}
%if %suse_version < 1210
# Due to lack of generated requires in old rpm, force this
Requires:       ocaml-compiler-libs
%endif

%description camlp4
Camlp4 is a Pre-Processor-Pretty-Printer for Objective Caml, parsing a
source file and printing some result on standard output.

This package contains the runtime files.


%package camlp4-devel
Summary:        Pre-Processor-Pretty-Printer for Objective Caml
License:        SUSE-LGPL-2.0-with-linking-exception
Group:          Development/Languages/Other
Requires:       %{name}-camlp4 = %{version}
Requires:       ocaml = %{version}
Provides:       camlp4 = %{version}
Obsoletes:      camlp4 < %{version}

%description camlp4-devel
Camlp4 is a Pre-Processor-Pretty-Printer for Objective Caml, parsing a
source file and printing some result on standard output.

This package contains the development files.


%package ocamldoc
Summary:        The Objective Caml Compiler and Programming Environment
License:        QPL-1.0
Group:          Development/Languages/Other
Requires:       ocaml = %{version}

%description ocamldoc
Objective Caml is a high-level, strongly-typed, functional and
object-oriented programming language from the ML family of languages.

This package contains a documentation generator for Objective Caml.



%package emacs
Summary:        The Objective Caml Compiler and Programming Environment
License:        GPL-2.0+
Group:          Development/Languages/Other
Requires:       emacs
Requires:       ocaml = %{version}
Provides:       caml-mode

%description emacs
Objective Caml is a high-level, strongly-typed, functional and
object-oriented programming language from the ML family of languages.

This package provides caml-mode for emacs



%package docs
Summary:        The Objective Caml Compiler and Programming Environment
License:        GPL-2.0+ and QPL-1.0
Group:          Development/Languages/Other
Requires:       ocaml = %{version}

%description docs
Objective Caml is a high-level, strongly-typed, functional and
object-oriented programming language from the ML family of languages.

This package comprises two batch compilers (a fast bytecode compiler
and an optimizing native-code compiler), an interactive top level
system, Lex&Yacc tools, a replay debugger, and a comprehensive library.

%package compiler-libs
Summary:        Libraries used internal to the OCaml Compiler
License:        QPL-1.0
Group:          Development/Libraries/Other
Requires:       ocaml = %{version}

%description compiler-libs
Objective Caml is a high-level, strongly-typed, functional and
object-oriented programming language from the ML family of languages.

This package contains several modules used internally by the OCaml
compilers. They are not needed for normal OCaml development, but may
be helpful in the development of certain applications.

%package compiler-libs-devel
Summary:        Libraries used internal to the OCaml Compiler
License:        QPL-1.0
Group:          Development/Libraries/Other
Requires:       ocaml-compiler-libs = %{version}

%description compiler-libs-devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.


%prep
%setup -q -T -b 0
%setup -q -T -D -a 1
%setup -q -T -D -a 3
%patch0 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5
%patch7
%patch8 -p1
%patch9 -p1

find -name ".cvsignore" | xargs -r rm -f

%build
%ifarch %ix86
# Default OPT flags for these architectures use -fomit-frame-pointer,
# which gets in the way of some of the profiling done within.
export RPM_OPT_FLAGS="${RPM_OPT_FLAGS/-fomit-frame-pointer/}"
%endif

# For ppc64 we need a larger stack than default to compile some files
# because the stages in the OCaml compiler are not mutually tail
# recursive.
%ifarch ppc64
ulimit -a
ulimit -Hs 65536
ulimit -Ss 65536
%endif
CFLAGS="$RPM_OPT_FLAGS -DUSE_INTERP_RESULT" \
./configure -bindir %{_bindir} \
            -libdir %{_libdir}/ocaml \
	    -mandir %{_mandir} \
            -x11include %{_includedir} \
            -x11lib %{_libdir}
%if %{do_opt}
make world.opt
%else
make world
%endif

%install
make install \
     BINDIR="$RPM_BUILD_ROOT%{_bindir}" \
     LIBDIR="$RPM_BUILD_ROOT%{_libdir}/ocaml" \
     MANDIR="$RPM_BUILD_ROOT%{_mandir}"
sed -i -e "s|^$RPM_BUILD_ROOT||" $RPM_BUILD_ROOT%{_libdir}/ocaml/ld.conf

install -d $RPM_BUILD_ROOT%{_infodir} \
           $RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp
(
  cd emacs
  make install BINDIR=$RPM_BUILD_ROOT/%{_bindir} EMACSDIR=$RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp
  make install-ocamltags BINDIR=$RPM_BUILD_ROOT/%{_bindir}
)

(
  cd infoman; cp -f ocaml* $RPM_BUILD_ROOT%{_infodir}
)

# fix bnc#411232
echo '(load "ocaml.el" nil t t)' >$RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp/suse-start-ocaml.el
cat <<EOF >$RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp/%{name}.el
(autoload 'caml-mode "caml" "Caml editing mode" t)
(add-hook 'caml-mode-hook 'font-lock-mode)
(add-to-list 'auto-mode-alist '("\\\\.mli?$" . caml-mode))
EOF
sed -i '1s/^/#!\/usr\/bin\/ocaml\n/' $RPM_BUILD_ROOT/%{_bindir}/ocamltags

export EXCLUDE_FROM_STRIP="ocamldebug ocamlbrowser"

# Install the compiler libs
install -d $RPM_BUILD_ROOT%{_libdir}/ocaml/compiler-libs
cp -a typing/ utils/ parsing/ $RPM_BUILD_ROOT%{_libdir}/ocaml/compiler-libs
%fdupes $RPM_BUILD_ROOT

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc Changes LICENSE README
%{_bindir}/*
%{_mandir}/*/*
%{_libdir}/ocaml/*.a
%if %{do_opt}
%{_libdir}/ocaml/*.cmxs
%{_libdir}/ocaml/*.cmxa
%{_libdir}/ocaml/*.cmx
%{_libdir}/ocaml/*.o
%endif
%{_libdir}/ocaml/*.mli
%{_libdir}/ocaml/libcamlrun_shared.so
%{_libdir}/ocaml/vmthreads/*.mli
%{_libdir}/ocaml/vmthreads/*.a
%if %{do_opt}
%{_libdir}/ocaml/threads/*.a
%{_libdir}/ocaml/threads/*.cmxa
%{_libdir}/ocaml/threads/*.cmx
%endif
%{_libdir}/ocaml/caml
%{_libdir}/ocaml/ocamlbuild
%{_libdir}/ocaml/Makefile.config
%{_libdir}/ocaml/VERSION
%{_libdir}/ocaml/extract_crc
%{_libdir}/ocaml/camlheader
%{_libdir}/ocaml/camlheader_ur
%{_libdir}/ocaml/expunge
%{_libdir}/ocaml/ld.conf
%{_libdir}/ocaml/objinfo_helper
%exclude %{_libdir}/ocaml/graphicsX11.mli
%{_infodir}/*
%exclude %{_bindir}/ocamlrun
%exclude %{_bindir}/camlp4*
%exclude %{_bindir}/mkcamlp4
%exclude %{_bindir}/labltk
%exclude %{_bindir}/ocamltags
%exclude %{_bindir}/ocamlbrowser
%exclude %{_bindir}/ocamldoc*
%exclude %{_libdir}/ocaml/camlp4
%exclude %{_libdir}/ocaml/labltk
%exclude %{_libdir}/ocaml/ocamldoc
%exclude %{_libdir}/ocaml/stublibs/dlllabltk.so

%files runtime
%defattr(-,root,root,-)
%{_bindir}/ocamlrun
%dir %{_libdir}/ocaml
%{_libdir}/ocaml/*.cmo
%{_libdir}/ocaml/*.cmi
%{_libdir}/ocaml/*.cma
%{_libdir}/ocaml/stublibs
%dir %{_libdir}/ocaml/vmthreads
%{_libdir}/ocaml/vmthreads/*.cmi
%{_libdir}/ocaml/vmthreads/*.cma
%dir %{_libdir}/ocaml/threads
%{_libdir}/ocaml/threads/*.cmi
%{_libdir}/ocaml/threads/*.cma
%exclude %{_libdir}/ocaml/graphicsX11.cmi
%exclude %{_libdir}/ocaml/stublibs/dlllabltk.so
%doc README LICENSE Changes

%files x11
%defattr(-,root,root,-)
%{_libdir}/ocaml/graphicsX11.cmi
%{_libdir}/ocaml/graphicsX11.mli

%files source
%defattr(-,root,root,-)
%{_libdir}/ocaml/*.ml

%files labltk
%defattr(-,root,root,-)
%{_bindir}/labltk
%dir %{_libdir}/ocaml/labltk
%{_libdir}/ocaml/labltk/*.cmi
%{_libdir}/ocaml/labltk/*.cma
%{_libdir}/ocaml/labltk/*.cmo
%{_libdir}/ocaml/stublibs/dlllabltk.so

%files labltk-devel
%defattr(-,root,root,-)
%{_bindir}/ocamlbrowser
%{_libdir}/ocaml/labltk/labltktop
%{_libdir}/ocaml/labltk/pp
%{_libdir}/ocaml/labltk/tkcompiler
%if %{do_opt}
%{_libdir}/ocaml/labltk/*.a
%{_libdir}/ocaml/labltk/*.cmxa
%{_libdir}/ocaml/labltk/*.cmx
%{_libdir}/ocaml/labltk/*.o
%endif
%{_libdir}/ocaml/labltk/*.mli
%doc otherlibs/labltk/examples_labltk
%doc otherlibs/labltk/examples_camltk

%files camlp4
%defattr(-,root,root,-)
%dir %{_libdir}/ocaml/camlp4
%{_libdir}/ocaml/camlp4/*.cmi
%{_libdir}/ocaml/camlp4/*.cma
%{_libdir}/ocaml/camlp4/*.cmo
%dir %{_libdir}/ocaml/camlp4/Camlp4Filters
%{_libdir}/ocaml/camlp4/Camlp4Filters/*.cmi
%{_libdir}/ocaml/camlp4/Camlp4Filters/*.cmo
%dir %{_libdir}/ocaml/camlp4/Camlp4Parsers
%{_libdir}/ocaml/camlp4/Camlp4Parsers/*.cmo
%{_libdir}/ocaml/camlp4/Camlp4Parsers/*.cmi
%dir %{_libdir}/ocaml/camlp4/Camlp4Printers
%{_libdir}/ocaml/camlp4/Camlp4Printers/*.cmi
%{_libdir}/ocaml/camlp4/Camlp4Printers/*.cmo
%dir %{_libdir}/ocaml/camlp4/Camlp4Top
%{_libdir}/ocaml/camlp4/Camlp4Top/*.cmi
%{_libdir}/ocaml/camlp4/Camlp4Top/*.cmo

%files camlp4-devel
%defattr(-,root,root,-)
%{_bindir}/camlp4*
%{_bindir}/mkcamlp4
%if %{do_opt}
%{_libdir}/ocaml/camlp4/*.a
%{_libdir}/ocaml/camlp4/*.cmxa
%{_libdir}/ocaml/camlp4/*.cmx
%{_libdir}/ocaml/camlp4/*.o
%{_libdir}/ocaml/camlp4/Camlp4Filters/*.cmx
%{_libdir}/ocaml/camlp4/Camlp4Filters/*.o
%{_libdir}/ocaml/camlp4/Camlp4Parsers/*.cmx
%{_libdir}/ocaml/camlp4/Camlp4Parsers/*.o
%{_libdir}/ocaml/camlp4/Camlp4Printers/*.cmx
%{_libdir}/ocaml/camlp4/Camlp4Printers/*.o
%{_libdir}/ocaml/camlp4/Camlp4Top/*.cmx
%{_libdir}/ocaml/camlp4/Camlp4Top/*.o
%endif

%files ocamldoc
%defattr(-,root,root,-)
%{_bindir}/ocamldoc*
%{_libdir}/ocaml/ocamldoc
%doc ocamldoc/Changes.txt

%files docs
%defattr(-,root,root,-)
%doc htmlman

%files emacs
%defattr(-,root,root,-)
%doc emacs/README
%dir %{_datadir}/emacs
%dir %{_datadir}/emacs/site-lisp
%{_datadir}/emacs/site-lisp/*
%{_bindir}/ocamltags

%files compiler-libs
%defattr(-,root,root,-)
%doc LICENSE README
%{_libdir}/ocaml/compiler-libs
%if %{do_opt}
%exclude %{_libdir}/ocaml/compiler-libs/*/*.cmx
%exclude %{_libdir}/ocaml/compiler-libs/*/*.o
%endif
%exclude %{_libdir}/ocaml/compiler-libs/*/*.mli
%exclude %{_libdir}/ocaml/compiler-libs/*/*.ml

%files compiler-libs-devel
%defattr(-,root,root,-)
%doc LICENSE README
%if %{do_opt}
%{_libdir}/ocaml/compiler-libs/*/*.cmx
%{_libdir}/ocaml/compiler-libs/*/*.o
%endif
%{_libdir}/ocaml/compiler-libs/*/*.ml
%{_libdir}/ocaml/compiler-libs/*/*.mli

%changelog
* Sat Feb  1 2014 ohering@suse.de
- Disable opt on aarch64
* Thu Jan 30 2014 ohering@suse.de
- Provide ocaml(ocaml.opt)==version if available
* Fri Dec  6 2013 matz@suse.de
- Disable opt on ppc64le (ocaml-ppc64.patch doesn't support ELVv2)
* Thu Sep 19 2013 ohering@suse.de
- update version 4.01.0
  * http://caml.inria.fr/pub/distrib/ocaml-4.01/notes/Changes
  add ocaml-yacc-Use-mkstemp-instead-of-mktemp.patch
  rename obsolete ocaml-rpmoptflags.patch to
  ocaml-configure-Allow-user-defined-C-compiler-flags.patch
  remove obsolete ocaml-tcl86.patch
  remove obsolete ocaml-3.08.3.patch
* Tue Sep 10 2013 guillaume@opensuse.org
- Fix ARM build
* Thu Aug  1 2013 max@suse.com
- Added ocaml-tcl86.patch to fix build with Tcl 8.6.
* Mon Jun  3 2013 ohering@suse.de
- Recompress with xz
* Fri Mar 22 2013 dvaleev@suse.com
- refresh ocaml-ppc64.patch
- increase stack size for ppc64
- package back *cmxs files for ppc
* Thu Feb 21 2013 ohering@suse.de
- add hard requires ocaml-compiler-libs in ocaml-camlp4 in
  versions before 12.1 due to lack of autorequires in old rpm
* Thu Feb 21 2013 ohering@suse.de
- disable opt on ia64
* Fri Feb 15 2013 i@marguerite.su
- update version 4.00.1
  * http://caml.inria.fr/pub/distrib/ocaml-4.00/notes/Changes
- remove ocaml-3.04-info.patch, upstream fixed.
- remove arm-add-type-directive.patch, upstream fixed.
* Mon Jan 14 2013 ohering@suse.de
- change Requires: version-release to just Requires: version
* Wed Jan  2 2013 ohering@suse.de
- update specfile to handle disabled do_opt variable
* Wed Jun 27 2012 dvaleev@suse.com
- refresh ppc64 patch
- Link dllthreads.so with -lpthread so that pthread_atfork
  is included statically.
* Thu May 10 2012 cfarrell@suse.com
- license update: QPL-1.0 and SUSE-LGPL-2.0-with-linking-exception
  Use SPDX format (http://www.spdx.org/licenses). Where there is no
  suitable shortname available on spdx.org check the spreadsheet linked at
  license.opensuse.org
* Tue Jan 31 2012 dvaleev@suse.com
- *.cmxs doesn't built for ppc
* Mon Dec 19 2011 coolo@suse.com
- fix Source references to contain original upstream
* Mon Nov 14 2011 dmueller@suse.de
- add add .type directive for code symbols (needed on arm)
* Tue Nov  8 2011 dvaleev@suse.com
- enable ppc64 build
* Thu Sep 15 2011 ampsaltis@gmail.com
- Explicitly require the ocaml-runtime package in the ocaml package
* Thu Sep 15 2011 ampsaltis@gmail.com
- The ocaml package does not provide the runtime any more.
* Fri Jul 22 2011 ampsaltis@gmail.com
- Unremove code block regarding removing -fomit-frame-pointer within RPM_OPT_FLAGS for ix86 architectures
* Thu Jul 21 2011 ampsaltis@gmail.com
- Enable optimizations (Fedora does this)
- More cleanup done
* Thu Jul 21 2011 ampsaltis@gmail.com
- Clean up spec file
- Remove ocaml-3.12-fix-size-directive.patch
* Tue Jul  5 2011 ampsaltis@gmail.com
- New upstream version 3.12.1, providing many bugfixes.
- ocaml-3.12-fix-size-directive.patch is no longer needed.
* Sun Jun 19 2011 ampsaltis@gmail.com
- Add compiler library packages
* Sun Jun 19 2011 ampsaltis@gmail.com
- Obsolete old "camlp4" package
* Fri Jun 17 2011 ampsaltis@gmail.com
- Split (and rename) camlp4 package.  Add provide for consistency.
- Decomment some stuff.
* Fri May 27 2011 ampsaltis@gmail.com
- Make the spec work with older versions of RPM
- Split some parts of packages for devel-ness
* Tue May 24 2011 coolo@novell.com
- add provides required by the rpm-4.9 auto provides
* Mon May 23 2011 coolo@novell.com
- fix for last change to also include interpreter
* Sat May 21 2011 jslaby@suse.de
- fix build with rpm 4.9.0
* Wed Apr 27 2011 vcizek@novell.com
- license correction to GPLv2 and QPL
- removed author from spec
* Tue Apr 26 2011 idoenmez@novell.com
- Add ocaml-3.12-fix-size-directive.patch:
  incorrect .size directives generated for x86-32 and x86-64
* Tue Aug 24 2010 anicka@suse.cz
- update to 3.12.0
  * While fixing PR#4824, also corrected a gaping hole in the type checker,
  which allowed instantiating separately object parameters and instance
  variables in an interface. This hole was here since the beginning of
  ocaml, and as a result many programs using object inheritance in a non
  trivial way will need to be corrected. You can look at lablgtk2 for an
  example.
  * new language features, bugfixes
* Mon Jan 11 2010 vuntz@opensuse.org
- Remove unneeded gtk-devel BuildRequires.
* Fri Dec 11 2009 anicka@suse.cz
- update to 1.11.1
  * bug fixes
  * Improved wording of various error messages
  * Support for 64-bit mode in Solaris/x86 (PR#4670).
* Tue Jun  9 2009 coolo@novell.com
- filter out fomit-frame-pointer from rpm_opt_flags to fix build
* Tue Feb 17 2009 anicka@suse.cz
- update to 1.11.0
  * major relase with many changes, language enhancements and bugfixes
  * backward incompatible changes:
  * Revised -output-obj: the output name
    must now be provided; its extension must be one of .o/.obj,
    .so/.dll, or .c for the bytecode compiler. The compilers can
    now produce a shared library (with all the needed -ccopts/-ccobjs
    options) directly.
  * programs linked with camlp4lib.cma now also need dynlink.cma
- remove type_punning and tk8.5 patches (not needed anymore)
- drop ppc64 patch
- use %%fdupes macro to reduce size of the package
* Thu Jul 24 2008 anicka@suse.cz
- fix loading caml-mode in emacs (bnc#411232)
* Thu Jul 10 2008 olh@suse.de
- build also on ppc64 (fate#304103)
* Wed Apr  9 2008 anicka@suse.cz
- update to 3.10.2
  * PR#1217 (partial) Typo in ocamldep man page
  * PR#3952 (partial) ocamlopt: allocation problems on ARM
  * PR#4339 (continued) ocamlopt: problems on HPPA
  * PR#4455 str.mli not installed under Windows
  * PR#4473 crash when accessing float array with polymorphic method
  * PR#4480 runtime would not compile without gcc extensions
  * PR#4481 wrong typing of exceptions with object arguments
  * PR#4490 typo in error message
  * Random crash on 32-bit when major_heap_increment >= 2^22
  * Big performance bug in Weak hashtables
  * Small bugs in the make-package-macosx script
  * Bug in typing of polymorphic variants (reported on caml-list)
* Mon Apr  7 2008 anicka@suse.cz
- fix build for tk 8.5
* Mon Mar 10 2008 anicka@suse.cz
- update to 3.10.1
  - made configure script work on PlayStation 3
  - ARM port: brought up-to-date for Debian 4.0 (Etch)
  - many other small changes and bugfixes in camlp4, ocamlbuild, labltk,
  emacs files,
  - Added virtual instance variables in classes "val virtual v : t"
  * Changed the behaviour of instance variable overriding; the new
  definition replaces the old one, rather than creating a new
  variable.
  - ocamlbuild: compilation manager for OCaml applications and libraries.
  See draft documentation at http://gallium.inria.fr/~pouillar/
  * Camlp4: heavily revised implementation, new API.
  - Faster type-checking of functor applications.
  - Referencing an interface compiled with -rectypes from a module
    not compiled with -rectypes is now an error.
  - Revised the "fragile matching" warning.
  - Print a stack backtrace on an uncaught exception.
  (Compile and link with ocamlopt -g; execute with OCAMLRUNPARAM=b.)
  Supported on Intel/AMD in 32 and 64 bits, PPC in 32 and 64 bits.
  - Stack overflow detection on MS Windows 32 bits (courtesy O. Andrieu).
  - Stack overflow detection on MacOS X PPC and Intel.
  - Intel/AMD 64 bits: generate position-independent code by default.
  - Fixed bug involving -for-pack and missing .cmx files (PR#4124).
  - Fixed bug causing duplication of literals  (PR#4152).
  - C/Caml interface functions take "char const *" arguments
  instead of "char *" when appropriate.
  - Faster string comparisons (fast case if strings are ==).
* Wed Nov 28 2007 ro@suse.de
- added -O0 to optflags for now on x86 (#343760)
* Sun Nov  4 2007 ro@suse.de
- updated rpmlintrc
* Fri Jun 15 2007 ro@suse.de
- clean up specfile a bit (thanks to dirk stoecker)
* Wed May 16 2007 ro@suse.de
- split up package similar to f-e
- update to 3.09.3
  * featurelist
  - ocamldoc: name resolution in cross-referencing {!name}: if name is not
    found, then it is searched in the parent module/class, and in the parent
    of the parent, and so on until it is found.
  - ocamldoc: new option -short-functors to use a short form to display
    functors in html generator PR#4017
  - ocamlprof: added "-version" option
  - ported to MacOS X on Intel PR#3985
  - configure: added support for GNU Hurd PR#3991
  - otherlibs/labltk: browser uses menu bars instead of menu buttons
  - Introduction of private row types, for abstracting the row in object
    and variant types.
  - configure: find X11 config in some 64-bit Linux distribs
  - ocamldoc: (**/**) can be canceled with another (**/**) PR#3665
  - graphics: added resize_window
  - graphics: check for invalid arguments to drawing primitives PR#3595
  - ocamlbrowser: use windows subsystem on mingw
  * disruptive changes
  * Revised implementation of the -pack option (packing of several compilation
    units into one).  The .cmx files that are to be packed with
    "ocamlopt -pack -o P.cmx" must be compiled with "ocamlopt -for-pack P".
    In exchange for this additional constraint, ocamlopt -pack is now
    available on all platforms (no need for binutils).
  * Fixed wrong evaluation order for arguments to certain inlined functions.
* Thu Mar 29 2007 rguenther@suse.de
- add emacs site-lisp directories
* Fri Mar 23 2007 rguenther@suse.de
- add gdbm-devel and ncurses-devel BuildRequires
* Thu Aug 17 2006 cthiel@suse.de
- fix build with X.Org 7.1
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu May 12 2005 ro@suse.de
- update to 3.08.3
- reduce register pressure in bng_ia32.c (thanks to matz)
* Tue Sep 14 2004 jj@suse.de
- version update (done by pthomas)
* Wed Apr 28 2004 ro@suse.de
- added -fno-strict-aliasing also to native build
* Mon Apr 19 2004 mmj@suse.de
- declare void functions as such
* Sat Jan 10 2004 adrian@suse.de
- use x-devel-packages
* Sat Jun 21 2003 mmj@suse.de
- Own all dirs
* Wed May 21 2003 coolo@suse.de
- fix man page installation
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Mon Apr  7 2003 mmj@suse.de
- head -1 is head -n 1 with the new coreutils
* Tue Feb 11 2003 mmj@suse.de
- Use %%install_info macro [#23440]
* Tue Sep 17 2002 uli@suse.de
- update -> 3.0.6 (needed for mldonkey)
* Mon Jun 17 2002 meissner@suse.de
- copy over config.* from libtool repository and other ppc64 fixes.
* Mon May 27 2002 ro@suse.de
- fix installation in camlp4 directory (bindir was without
  buildroot prefix)
* Fri May 24 2002 mmj@suse.de
- Disabling build of optional architecture specific stuff on plat-
  forms where ocaml does not procide the necessary asm parts.
* Wed May 15 2002 schwab@suse.de
- Fix neededforbuild.
* Mon May 13 2002 mmj@suse.de
- Update to 3.04, maily bugfix release
* Tue Jan 15 2002 schwab@suse.de
- Fix for ia64.
* Thu Aug 16 2001 grimmer@suse.de
- initial SuSE package (version 3.02), added to be able to build
  package "unison"
- spec file derived from Mandrake Linux source RPM (thanks, pixel!)
